/*** analhead.h: header file for prostat 1.32  ***/

/*** Change any of these according to your desires ***/

#ifndef ANALHEAD
#define ANALHEAD

#define DIRSUFFIX "index.html"
/* the default filename tried if a directory is requested. The program
   combines statistics from /dir/ and /dir/DIRSUFFIX. If you don't wish
   this combining to occur, define DIRSUFFIX to be "". The usual value
   is "index.html". In future versions there will be support for more
   than one value, for servers that support that. */

#define URLHASHSIZE (659)
/* the size of the hash table for URLs; must be odd, should be prime. */
/* too small will make the program slower; too big might use a bit */
/* more memory and be slightly less efficient. Maybe half the number */
/* of URLs expected, but it shouldn't be at all critical. There is a list */
/* of primes in the file primes.tab */

#define PROTOHASHSIZE (97)
/* ditto for directories */

#define REQUESTHASHSIZE (97)

/*#define HOSTHASHSIZE (5087)*/
#define HOSTHASHSIZE (5197)
/* ditto for all hostnames that have accessed us */

#define MAXLINELENGTH (2048)
/* the maximum length of any line in the logfile (long lines can
   result from searches), domains file or rc file. Longer lines
   will be thrown away. */

#define MAXSTRINGLENGTH (256)
/* how long is the longest string we want for our
   organisation name, an internet address or geographical location?
   (Longer strings will be truncated). */
#define MAXURL (1000)

#define MINPAGEWIDTH (25)
#define MAXPAGEWIDTH (240)
/* the min and max allowed values of the pagewidth variable */

/*** The following options can be overriden in the configuration file, but
     not on the commandline ***/

#define LANG "FR"
/* the language for output. Can be FR (french) or EN (english) */

#define WEEKBEGINSON (SUNDAY)
/* The 1st day of the week. I think it's SUNDAY, but you can choose any day. */

#define SEPCHAR ' '
/* The character to separate the thousands in a long number. I prefer ' ',
   but some people prefer '.' or ','. Use '9' if you really want to inflate
   your statistics! :) */

#define REPORTORDER "SrDPdhmt"
/* A string like "mWdDhoSir" giving the order in which the reports will be
   output. You should make sure to include each of the above letters exactly
   once or you will not get some report even if you specifically request it
   later, or you may get some report twice. */

#define BACKGROUND "none"
/* URL of background image to appear on the output page. Preferably use "none"
   for none. If you must use one (i) it should be small, otherwise people
   with slow lines won't be able to load your page (ii) it should not stop
   people with low res. monochrome screens being able to read your page. */

#define BASEURL "none"
/* A string which is prepended to all URLs linked to in the request report.
   This is useful if you want to display the statistics on a different
   server from the one that generated the logfile. Use "none" for none. */

#define DOMCOLS "RrBb"
/* Which columns we want to appear in the domain report, and in which order.
   The string can contain any of the following four letters:
   R   Number of requests from each domain
   r   Percentage of the requests from each domain
   B   Total number of bytes transferred to each domain
   b   The percentage of traffic to each domain                            */

/* And the same for the host report, directory report and request report */
#define HOSTCOLS "RrBb"
#define PROTOCOLS "RrBb"
#define SITESCOLS "RrBb"
#define TYPECOLS "RrBb"
#define MIMECOLS "RrBb"

/*** ALL the options from here on can be overridden on the command line,
     or in the configuration file (except CONFIGFILE!) ***/ 

#define LOGFILE "/spare1/logs/access.log.0"
/* The name of the default logfile; use "stdin" for stdin */
/* Overridden by argument without + or -, or by just '-' for stdin. */

#define OUTDIR "stdout"
/* the default directory for output. Use "stdout" for stdout. */

#define DOMAINSFILE "/usr/local/etc/domains.tab"
/* the name of the file where the domain definitions live; see README.html
   for the format of this file */
/* Overridden by -f */

#define TYPESFILE "/usr/local/etc/mime.types"

#define HEADERFILE "none"
/* an extra file (with HTML markup if desired) placed between the page title
   and the start of the statistics. Use "none" for none. */
/* Overridden by +H/-H */

#define FOOTERFILE "none"
/* And one placed at the bottom of the page */
/* Overridden by +F/-F */

#define ASCII (OFF)
/* Whether the output should be in ASCII or HTML by default */
/* Overridden by +a/-a */

#define LOGOURL "http://cache.cnrs.fr/images/LogoCNRSMoyen.gif"
/* the URL of the file where your logo lives. */
/* Overridden by +p */

#define LOGO (ON)
/* whether to include a logo. Overridden by +l/-l */

#define CONFIGFILE "/usr/local/etc/prostat.conf"
/* the name of the configuration file; see README.html for a description
   of this file. Use "none" for no configuration file. */
/* Overridden by +g/-g */

#define HOSTNAME "Cache National Renater"
/* the name of your organisation or WWW host. This is used for printing
   at the top of the output */
/* Overridden by -n */

#define HOSTURL "http://www.serveurs-nationaux.jussieu.fr/cache/"
/* the URL of your host's home page, for linking to at the top of the
   output; use "-" for no linking. */
/* Overridden by -u */

#define DEBUG (0)
/* Level of debugging output: 0 = none, 1 = print all corrupt lines to stderr,
   2 = also print hosts with unknown domains. */

#define MIN_URL_REQS (10)
/* the min. no. of requests a URL should have before appearing on the
   request report. Setting this to about 10 clears out a lot of junk.
   Setting it to a negative number gives a "top n" report. */
/* Overridden in +r */

#define MIN_URL_BYTES (1)
/* if we are sorting by bytes, use this instead; it is measured in 1/100ths
of percentage of total bytes transferred. (Or "top n" if negative again). */
/* Overridden in +r */

/* now the same for directory, domain and hostname reports. */
#define MIN_TYPE_REQS (1)
#define MIN_MIME_REQS (1)
#define MIN_TYPE_BYTES (1)
#define MIN_PROTO_REQS (10)
#define MIN_PROTO_BYTES (1)
/* Overridden in +i */
#define MIN_DOM_REQS (1) 
#define MIN_DOM_BYTES (0)
/* Overridden in +o */
#define MIN_HOST_REQS (100)
/* Set this quite high if you want it to finish in reasonable time */
#define MIN_HOST_BYTES (1)
/* Overridden in +S */

/* how should the request report, domain report and directory report be
   sorted? Legal values ar BYREQUESTS, BYBYTES and ALPHABETICAL */
#define SITESSORTBY (BYREQUESTS)
/* Overridden in +r */
#define DOMSORTBY (BYBYTES)
/* Overridden in +o */
#define PROTOSORTBY (BYBYTES)
/* Overridden in +i */
#define HOSTSORTBY (ALPHABETICAL)
/* Overridden in +S */
#define TYPESORTBY (BYREQUESTS)
/* Overridden in + */

#define MARKCHAR '+'
/* a character for the graphical displays */
/* Overridden by -c */

#define PAGEWIDTH (65)
/* the width of the output. Standard text screens have 80 columns, but for
   WWW browsers something like 65 is probably better. */
/* Overridden by -w */

/* whether we want each of the reports by default */
#define GENERAL (ON)
/* General summary and "Go To" links; overridden by +x/-x */
#define MONTHLY (ON)
/* Overridden by +m/-m */
#define DAILY (ON)
/* Overridden by +d/-d */
#define HOURLY (ON)
/* Overridden by +h/-h */
#define DOMAINS (ON)
/* Overridden by +D/-D */
#define PROTOCOL (ON)
/* Overridden by +P/-P */
#define SITES (ON)
/* Overridden by +s/-s */
#define REQUESTS (ON)
/* Overridden by +R/-R */
#define HOSTS (OFF)
/* Full hostname report. Typically very long output and slow to produce
   on a full logfile, unless MIN_HOST_REQS or _BYTES is high as applicable */
/* Overridden by +S */

#define FILETYPE (OFF)
#define MIMETYPE (ON)
#define GRAPH (ON)
#define CUMUL (ON)

#define REQTYPE (ALL)
/* do we want to show ALL requests in the request report or just PAGES? */
/* Overridden by +r*/

#define PAGELINKS (ON)
/* whether pages are linked to in the request report by default. */
/* Can be OFF, ON (link to pages) or ALL (link to everything). */
/* Overridden by +k/-k */

#define NUMLOOKUP (OFF)
/* whether we want to look up numerical addresses at run time to try
   and resolve them. This can get very slow. */
/* Overridden by +1/-1 */

/* the default values for the value of each MARKCHAR on the graphs.
   0 means choose a sensible value at the time based on number of requests
   and the value of PAGEWIDTH. */
#define MONTHLYUNIT (0)
/* Overridden in +m */
#define HOURLYUNIT (0)
/* Overridden in +h */
#define DAILYUNIT (0)
/* Overridden in +d */
#define FULLDAILYUNIT (0)
/* Overridden in +D */

#endif
